@@ -56,13 +56,13 @@ const (
 	// 500 KiB of alerts is limit, one alert line has typically 450 bytes => 1137 lines.
 	// This number has been rounded to 1000 for simplicity.
 	// Formerly, the `500 * 1024 / 450` expression was used instead.
-	metricsAlertsLinesLimit = 1000
+	metricsAlertsLinesLimit        = 1000
 	gatherPodDisruptionBudgetLimit = 5000
 )
 
 var (
-	openshiftSerializer = openshiftscheme.Codecs.LegacyCodec(configv1.SchemeGroupVersion)
-	kubeSerializer      = kubescheme.Codecs.LegacyCodec(corev1.SchemeGroupVersion)
+	openshiftSerializer     = openshiftscheme.Codecs.LegacyCodec(configv1.SchemeGroupVersion)
+	kubeSerializer          = kubescheme.Codecs.LegacyCodec(corev1.SchemeGroupVersion)
 	policyV1Beta1Serializer = kubescheme.Codecs.LegacyCodec(policyv1beta1.SchemeGroupVersion)
 
 	// maxEventTimeInterval represents the "only keep events that are maximum 1h old"
@@ -90,6 +90,7 @@ func init() {
 
 // Gatherer is a driving instance invoking collection of data
 type Gatherer struct {
+	ctx            context.Context
 	client         configv1client.ConfigV1Interface
 	coreClient     corev1client.CoreV1Interface
 	networkClient  networkv1client.NetworkV1Interface
@@ -121,6 +122,7 @@ var reInvalidUIDCharacter = regexp.MustCompile(`[^a-z0-9\-]`)
 
 // Gather is hosting and calling all the recording functions
 func (i *Gatherer) Gather(ctx context.Context, recorder record.Interface) error {
+	i.ctx = ctx
 	return record.Collect(ctx, recorder,
 		GatherPodDisruptionBudgets(i),
 		GatherMostRecentMetrics(i),
@@ -153,14 +155,18 @@ func (i *Gatherer) Gather(ctx context.Context, recorder record.Interface) error
 // See: docs/insights-archive-sample/config/pdbs
 func GatherPodDisruptionBudgets(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		pdbs, err := i.policyClient.PodDisruptionBudgets("").List(metav1.ListOptions{Limit: gatherPodDisruptionBudgetLimit})
+		pdbs, err := i.policyClient.PodDisruptionBudgets("").List(i.ctx, metav1.ListOptions{Limit: gatherPodDisruptionBudgetLimit})
 		if err != nil {
 			return nil, []error{err}
 		}
 		records := []record.Record{}
 		for _, pdb := range pdbs.Items {
+			recordName := fmt.Sprintf("config/pdbs/%s", pdb.GetName())
+			if pdb.GetNamespace() != "" {
+				recordName = fmt.Sprintf("config/pdbs/%s/%s", pdb.GetNamespace(), pdb.GetName())
+			}
 			records = append(records, record.Record{
-				Name: fmt.Sprintf("config/pdbs/%s", pdb.GetName()),
+				Name: recordName,
 				Item: PodDisruptionBudgetsAnonymizer{&pdb},
 			})
 		}
@@ -187,7 +193,7 @@ func GatherMostRecentMetrics(i *Gatherer) func() ([]record.Record, []error) {
 		data, err := i.metricsClient.Get().AbsPath("federate").
 			Param("match[]", "etcd_object_counts").
 			Param("match[]", "cluster_installer").
-			DoRaw()
+			DoRaw(i.ctx)
 		if err != nil {
 			// write metrics errors to the file format as a comment
 			klog.Errorf("Unable to retrieve most recent metrics: %v", err)
@@ -196,7 +202,7 @@ func GatherMostRecentMetrics(i *Gatherer) func() ([]record.Record, []error) {
 
 		rsp, err := i.metricsClient.Get().AbsPath("federate").
 			Param("match[]", "ALERTS").
-			Stream()
+			Stream(i.ctx)
 		if err != nil {
 			// write metrics errors to the file format as a comment
 			klog.Errorf("Unable to retrieve most recent alerts from metrics: %v", err)
@@ -240,7 +246,7 @@ func GatherMostRecentMetrics(i *Gatherer) func() ([]record.Record, []error) {
 // Location of pods in archive: config/pod/
 func GatherClusterOperators(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		config, err := i.client.ClusterOperators().List(metav1.ListOptions{})
+		config, err := i.client.ClusterOperators().List(i.ctx, metav1.ListOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -259,7 +265,7 @@ func GatherClusterOperators(i *Gatherer) func() ([]record.Record, []error) {
 				continue
 			}
 			for _, namespace := range namespacesForOperator(&item) {
-				pods, err := i.coreClient.Pods(namespace).List(metav1.ListOptions{})
+				pods, err := i.coreClient.Pods(namespace).List(i.ctx, metav1.ListOptions{})
 				if err != nil {
 					klog.V(2).Infof("Unable to find pods in namespace %s for failing operator %s", namespace, item.Name)
 					continue
@@ -331,7 +337,7 @@ func GatherClusterOperators(i *Gatherer) func() ([]record.Record, []error) {
 // collectContainerLogs fetches log lines from the pod
 func collectContainerLogs(i *Gatherer, pod *corev1.Pod, buf *bytes.Buffer, containerName string, isPrevious bool, maxBytes *int64) error {
 	req := i.coreClient.Pods(pod.Namespace).GetLogs(pod.Name, &corev1.PodLogOptions{Previous: isPrevious, Container: containerName, LimitBytes: maxBytes, TailLines: &logTailLines})
-	readCloser, err := req.Stream()
+	readCloser, err := req.Stream(i.ctx)
 	if err != nil {
 		klog.V(2).Infof("Failed to fetch log for %s pod in namespace %s for failing operator %s (previous: %v): %q", pod.Name, pod.Namespace, containerName, isPrevious, err)
 		return err
@@ -360,7 +366,7 @@ func collectContainerLogs(i *Gatherer, pod *corev1.Pod, buf *bytes.Buffer, conta
 // Location in archive: config/node/
 func GatherNodes(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		nodes, err := i.coreClient.Nodes().List(metav1.ListOptions{})
+		nodes, err := i.coreClient.Nodes().List(i.ctx, metav1.ListOptions{})
 		if err != nil {
 			return nil, []error{err}
 		}
@@ -386,7 +392,7 @@ func GatherNodes(i *Gatherer) func() ([]record.Record, []error) {
 // See: docs/insights-archive-sample/config/configmaps
 func GatherConfigMaps(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		cms, err := i.coreClient.ConfigMaps("openshift-config").List(metav1.ListOptions{})
+		cms, err := i.coreClient.ConfigMaps("openshift-config").List(i.ctx, metav1.ListOptions{})
 		if err != nil {
 			return nil, []error{err}
 		}
@@ -413,7 +419,7 @@ func GatherConfigMaps(i *Gatherer) func() ([]record.Record, []error) {
 // See: docs/insights-archive-sample/config/version
 func GatherClusterVersion(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		config, err := i.client.ClusterVersions().Get("version", metav1.GetOptions{})
+		config, err := i.client.ClusterVersions().Get(i.ctx, "version", metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -451,7 +457,7 @@ func GatherClusterID(i *Gatherer) func() ([]record.Record, []error) {
 // See: docs/insights-archive-sample/config/infrastructure
 func GatherClusterInfrastructure(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		config, err := i.client.Infrastructures().Get("cluster", metav1.GetOptions{})
+		config, err := i.client.Infrastructures().Get(i.ctx, "cluster", metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -471,7 +477,7 @@ func GatherClusterInfrastructure(i *Gatherer) func() ([]record.Record, []error)
 // See: docs/insights-archive-sample/config/network
 func GatherClusterNetwork(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		config, err := i.client.Networks().Get("cluster", metav1.GetOptions{})
+		config, err := i.client.Networks().Get(i.ctx, "cluster", metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -490,16 +496,16 @@ func GatherClusterNetwork(i *Gatherer) func() ([]record.Record, []error) {
 // Location in archive: config/hostsubnet/
 func GatherHostSubnet(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		hostSubnetList, err := i.networkClient.HostSubnets().List(metav1.ListOptions{})
+		hsList, err := i.networkClient.HostSubnets().List(i.ctx, metav1.ListOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
 		if err != nil {
 			return nil, []error{err}
 		}
-		records := make([]record.Record, 0, len(hostSubnetList.Items))
-		for _, h := range hostSubnetList.Items {
-			records = append(records, record.Record{Name: fmt.Sprintf("config/hostsubnet/%s", h.Host), Item: HostSubnetAnonymizer{&h}})
+		records := make([]record.Record, 0, len(hsList.Items))
+		for i, h := range hsList.Items {
+			records = append(records, record.Record{Name: fmt.Sprintf("config/hostsubnet/%s", h.Host), Item: HostSubnetAnonymizer{&hsList.Items[i]}})
 		}
 		return records, nil
 	}
@@ -514,7 +520,7 @@ func GatherHostSubnet(i *Gatherer) func() ([]record.Record, []error) {
 // See: docs/insights-archive-sample/config/authentication
 func GatherClusterAuthentication(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		config, err := i.client.Authentications().Get("cluster", metav1.GetOptions{})
+		config, err := i.client.Authentications().Get(i.ctx, "cluster", metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -530,7 +536,7 @@ func GatherClusterAuthentication(i *Gatherer) func() ([]record.Record, []error)
 // Location in archive: config/imagepruner/
 func GatherClusterImagePruner(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		pruner, err := i.registryClient.ImagePruners().Get("cluster", metav1.GetOptions{})
+		pruner, err := i.registryClient.ImagePruners().Get(i.ctx, "cluster", metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -546,7 +552,7 @@ func GatherClusterImagePruner(i *Gatherer) func() ([]record.Record, []error) {
 // Location in archive: config/imageregistry/
 func GatherClusterImageRegistry(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		config, err := i.registryClient.Configs().Get("cluster", metav1.GetOptions{})
+		config, err := i.registryClient.Configs().Get(i.ctx, "cluster", metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -566,7 +572,7 @@ func GatherClusterImageRegistry(i *Gatherer) func() ([]record.Record, []error) {
 // See: docs/insights-archive-sample/config/featuregate
 func GatherClusterFeatureGates(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		config, err := i.client.FeatureGates().Get("cluster", metav1.GetOptions{})
+		config, err := i.client.FeatureGates().Get(i.ctx, "cluster", metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -586,7 +592,7 @@ func GatherClusterFeatureGates(i *Gatherer) func() ([]record.Record, []error) {
 // See: docs/insights-archive-sample/config/oauth
 func GatherClusterOAuth(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		config, err := i.client.OAuths().Get("cluster", metav1.GetOptions{})
+		config, err := i.client.OAuths().Get(i.ctx, "cluster", metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -606,7 +612,7 @@ func GatherClusterOAuth(i *Gatherer) func() ([]record.Record, []error) {
 // See: docs/insights-archive-sample/config/ingress
 func GatherClusterIngress(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		config, err := i.client.Ingresses().Get("cluster", metav1.GetOptions{})
+		config, err := i.client.Ingresses().Get(i.ctx, "cluster", metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -626,7 +632,7 @@ func GatherClusterIngress(i *Gatherer) func() ([]record.Record, []error) {
 // See: docs/insights-archive-sample/config/proxy
 func GatherClusterProxy(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		config, err := i.client.Proxies().Get("cluster", metav1.GetOptions{})
+		config, err := i.client.Proxies().Get(i.ctx, "cluster", metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -646,7 +652,7 @@ func GatherClusterProxy(i *Gatherer) func() ([]record.Record, []error) {
 // Location in archive: config/certificatesigningrequests/
 func GatherCertificateSigningRequests(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
-		requests, err := i.certClient.CertificateSigningRequests().List(metav1.ListOptions{})
+		requests, err := i.certClient.CertificateSigningRequests().List(i.ctx, metav1.ListOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -674,7 +680,7 @@ func GatherCertificateSigningRequests(i *Gatherer) func() ([]record.Record, []er
 func GatherMachineSet(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
 		gvr := schema.GroupVersionResource{Group: "machine.openshift.io", Version: "v1beta1", Resource: "machinesets"}
-		machineSets, err := i.dynamicClient.Resource(gvr).List(metav1.ListOptions{})
+		machineSets, err := i.dynamicClient.Resource(gvr).List(i.ctx, metav1.ListOptions{})
 		if errors.IsNotFound(err) {
 			return nil, nil
 		}
@@ -683,8 +689,12 @@ func GatherMachineSet(i *Gatherer) func() ([]record.Record, []error) {
 		}
 		records := []record.Record{}
 		for _, i := range machineSets.Items {
+			recordName := fmt.Sprintf("machinesets/%s", i.GetName())
+			if i.GetNamespace() != "" {
+				recordName = fmt.Sprintf("machinesets/%s/%s", i.GetNamespace(), i.GetName())
+			}
 			records = append(records, record.Record{
-				Name: fmt.Sprintf("machinesets/%s", i.GetName()),
+				Name: recordName,
 				Item: record.JSONMarshaller{Object: i.Object},
 			})
 		}
@@ -697,7 +707,7 @@ func (i *Gatherer) gatherNamespaceEvents(namespace string) ([]record.Record, []e
 	if !strings.HasPrefix(namespace, "openshift-") {
 		return []record.Record{}, nil
 	}
-	events, err := i.coreClient.Events(namespace).List(metav1.ListOptions{})
+	events, err := i.coreClient.Events(namespace).List(i.ctx, metav1.ListOptions{})
 	if err != nil {
 		return nil, []error{err}
 	}
@@ -1065,7 +1075,6 @@ func (a PodDisruptionBudgetsAnonymizer) GetExtension() string {
 	return "json"
 }
 
-
 func isHealthyPod(pod *corev1.Pod, now time.Time) bool {
 	// pending pods may be unable to schedule or start due to failures, and the info they provide in status is important
 	// for identifying why scheduling has not happened
@@ -1146,8 +1155,13 @@ type HostSubnetAnonymizer struct{ *networkv1.HostSubnet }
 func (a HostSubnetAnonymizer) Marshal(_ context.Context) ([]byte, error) {
 	a.HostSubnet.HostIP = anonymizeString(a.HostSubnet.HostIP)
 	a.HostSubnet.Subnet = anonymizeString(a.HostSubnet.Subnet)
-	a.HostSubnet.EgressIPs = anonymizeSliceOfStrings(a.HostSubnet.EgressIPs)
-	a.HostSubnet.EgressCIDRs = anonymizeSliceOfStrings(a.HostSubnet.EgressCIDRs)
+
+	for i, s := range a.HostSubnet.EgressIPs {
+		a.HostSubnet.EgressIPs[i] = networkv1.HostSubnetEgressIP(anonymizeString(string(s)))
+	}
+	for i, s := range a.HostSubnet.EgressCIDRs {
+		a.HostSubnet.EgressCIDRs[i] = networkv1.HostSubnetEgressCIDR(anonymizeString(string(s)))
+	}
 	return runtime.Encode(networkSerializer.LegacyCodec(networkv1.SchemeGroupVersion), a.HostSubnet)
 }
 
